@@ -19,7 +19,10 @@ Various useful commands for working with bzr.
 """
 
 from bzrlib import ignores, option
-from bzrlib.commands import plugin_cmds
+from bzrlib.commands import (
+    builtin_command_names,
+    plugin_cmds,
+    )
 from version import version_info, __version__
 
 
@@ -27,7 +30,6 @@ ignores.add_runtime_ignores(['./.shelf'])
 
 
 commands = {
-    'cmd_branches': [],
     'cmd_branch_history': [],
     'cmd_cbranch': [],
     'cmd_cdiff': [],
@@ -53,6 +55,11 @@ for cmd_name, aliases in commands.items():
     plugin_cmds.register_lazy(cmd_name, aliases,
                               'bzrlib.plugins.bzrtools.command_classes')
 
+list_branches_aliases = (['branches'] if 'branches' not in
+                         builtin_command_names() else [])
+
+plugin_cmds.register_lazy('cmd_list_branches', list_branches_aliases,
+                          'bzrlib.plugins.bzrtools.command_classes')
 
 plugin_cmds.register_lazy('cmd_heads', [], 'bzrlib.plugins.bzrtools.heads')
 
