@@ -25,19 +25,13 @@ import sys
 
 import bzrlib
 from bzrlib import revision as _mod_revision, trace, urlutils
-import bzrlib.errors
 from bzrlib.errors import (
     BzrCommandError,
     BzrError,
-    ConnectionError,
     NotBranchError,
     NoSuchFile,
-    NoWorkingTree,
-    PermissionDenied,
-    UnsupportedFormatError,
-    TransportError,
     )
-from bzrlib.bzrdir import BzrDir, BzrDirFormat
+from bzrlib.bzrdir import BzrDir
 from bzrlib.transport import get_transport
 
 def temp_tree():
@@ -303,7 +297,7 @@ def rspush(tree, location=None, overwrite=False, working_tree=True,
         if working_tree:
             clean, non_source = is_clean(tree)
             if not clean:
-                raise bzrlib.errors.BzrCommandError(
+                raise BzrCommandError(
                     'This tree has uncommitted changes or unknown'
                     ' (?) files.  Use "bzr status" to list them.')
                 sys.exit(1)
@@ -319,16 +313,16 @@ def rspush(tree, location=None, overwrite=False, working_tree=True,
             try:
                 if not history_subset(push_location, tree.branch,
                                       _rsync=my_rsync):
-                    raise bzrlib.errors.BzrCommandError(
+                    raise BzrCommandError(
                         "Local branch is not a newer version of remote"
                         " branch.")
             except RsyncNoFile:
                 if not empty_or_absent(push_location):
-                    raise bzrlib.errors.BzrCommandError(
+                    raise BzrCommandError(
                         "Remote location is not a bzr branch (or empty"
                         " directory)")
             except RsyncStreamIO:
-                raise bzrlib.errors.BzrCommandError("Rsync could not use the"
+                raise BzrCommandError("Rsync could not use the"
                     " specified location.  Please ensure that"
                     ' "%s" is of the form "machine:/path".' % push_location)
         trace.note("Pushing to %s", push_location)
@@ -355,7 +349,7 @@ def apache_ls(t):
     t._remote_path = lambda x: t.base
     try:
         lines = t.get('')
-    except bzrlib.errors.NoSuchFile:
+    except NoSuchFile:
         return
     expr = re.compile('<a[^>]*href="([^>]*)\/"[^>]*>', flags=re.I)
     for line in lines:
