@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006, 2007 Aaron Bentley <aaron@aaronbentley.com>
+# Copyright (C) 2005, 2006, 2007, 2011 Aaron Bentley <aaron@aaronbentley.com>
 # Copyright (C) 2005, 2006, 2011 Canonical Limited.
 # Copyright (C) 2006 Michael Ellerman.
 #
@@ -16,8 +16,6 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import errno
-
 import bzrlib
 
 from bzrlib.lazy_import import lazy_import
@@ -26,24 +24,16 @@ from bzrlib import help, urlutils
 import shelf
 """)
 
+from bzrlib.plugins import bzrtools
 from command import BzrToolsCommand
 from errors import CommandError
 from patchsource import BzrPatchSource
-import sys
-import os.path
 
-import bzrlib.builtins
 import bzrlib.commands
 from bzrlib.branch import Branch
-from bzrlib.bzrdir import BzrDir
 from bzrlib.commands import get_cmd_object
 from bzrlib.errors import BzrCommandError
-import bzrlib.ignores
-from bzrlib.trace import note
 from bzrlib.option import Option, RegistryOption
-from bzrlib.workingtree import WorkingTree
-
-from command import BzrToolsCommand
 
 
 class cmd_graph_ancestry(BzrToolsCommand):
@@ -448,8 +438,13 @@ class cmd_cbranch(BzrToolsCommand):
                        hardlink=hardlink)
 
 
-class cmd_branches(BzrToolsCommand):
+class cmd_list_branches(BzrToolsCommand):
     """Scan a location for branches"""
+    @property
+    def aliases(self):
+        from bzrlib import commands
+        return commands.plugin_cmds.get_info('list-branches').aliases
+
     takes_args = ["location?"]
     def run(self, location=None):
         from branches import branches
